=====
perfm
=====


.. image:: https://img.shields.io/pypi/v/perfm.svg
        :target: https://pypi.org/project/perfm/

.. image:: https://img.shields.io/travis/gzxultra/perfm.svg
        :target: https://travis-ci.org/gzxultra/perfm

.. image:: https://readthedocs.org/projects/perfm/badge/?version=latest
        :target: https://perfm.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




performance stats counter for hpc programs


* Free software: MIT license
* Documentation: https://perfm.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
